@@ -37,10 +37,12 @@ class MujocsoException(Exception):
     pass
 
 class Mujocso:
-    def render(headers=None, page_title='Mujocso Page', style=[], script=[], template=None):
+    def render(headers=[], elements=[], page_title='Mujocso Page', style=[], script=[], template=None):
         global mujocso_location
 
         allowed_header_inputs = ['value', 'size']
+        alowed_element_inputs = ['type', 'value']
+        allowed_element_types = ['p', 'a', 'img']
         avaliable_styles = ['CBRORANGE', 'CENTERTITLEORANGE']
         avaliable_page_styles = []
         avaliable_templates = ['CBRO404']
@@ -48,6 +50,7 @@ class Mujocso:
         page_style = ''
         page_scripts = ''
 
+
         if(template != None):
             if(type(template) == str):
                 if(template.upper() in avaliable_templates):
@@ -78,20 +81,38 @@ class Mujocso:
                 page_scripts += script_+'\n'
 
         # Headers Validation
-        if(headers != None):
-            if(type(headers) == list):
-                for header in headers:
-                    if(type(header) == dict):
-                        for key in allowed_header_inputs:
-                            if(key in header and int(header['size']) <= 6):
-                                continue
-                            else:
-                                raise MujocsoException('Header values must be valid')
-                    else:
-                        raise MujocsoException('Header values must be a dictionary')
-            else:
-                raise MujocsoException('The headers must be a list')
+        if(type(headers) == list):
+            for header in headers:
+                if(type(header) == dict):
+                    for key in allowed_header_inputs:
+                        if(key in header and int(header['size']) <= 6):
+                            continue
+                        else:
+                            raise MujocsoException('Header values must be valid')
+                else:
+                    raise MujocsoException('Header values must be a dictionary')
+        else:
+            raise MujocsoException('The headers must be a list')
 
+        # Elements Validation
+        if(type(elements) == list):
+            for element in elements:
+                if(type(element) == dict):
+                    
+                    # Fix Img Error Passing Bug
+                    if(element['type'] == 'img'):
+                        alowed_element_inputs.append('src')
+                        alowed_element_inputs.append('alt')
+
+                    for key in alowed_element_inputs:
+                        if(key in element):
+                            continue
+                        else:
+                            raise MujocsoException('Element values must be valid')
+                else:
+                    raise MujocsoException('Element values must be a dictionary')
+        else:
+            raise MujocsoException('The elements must be a list')
         
         with io.open(file=mujocso_location+'/template_files/page.html', encoding='UTF-8') as page:
             o = page.read()
@@ -102,7 +123,7 @@ class Mujocso:
             )
         
         # Check And Processing Headers
-        if(headers != None and type(headers) == list):
+        if(type(headers) == list):
             for header in headers:
                 header_tag = 'h'+str(header['size'])
                 styles_temp = ''
@@ -155,6 +176,33 @@ class Mujocso:
                 ## -- Add To Body -- ##
                 page_body += add_to_body
                 page_body += '\n' 
+
+        if(type(elements) == list):
+            for element in elements:
+                element_tag = element_value = ''
+                element_addons = ' '
+                
+                if(element['type'] in allowed_element_types):
+                    # allowed_element_types[0] = <p> Tag
+                    if(element['type'] == allowed_element_types[0]):
+                        element_tag = element['type']
+                        element_value = element['value']
+                        
+
+                        if(len(element_tag) != 2):
+                            element_data_temp = element
+                            del element_data_temp['type']
+                            del element_data_temp['value']
+
+                            
+                            for param, value in element_data_temp.items():
+                                element_addons += param+'="'+str(value)+'" '
+
+                    add_to_body = '<'+element_tag+element_addons+'>'+element_value+'</'+element_tag+'>'
+                    page_body += add_to_body
+                    page_body += '\n' 
+                else:
+                    raise MujocsoException('Element type must be valid')
         
 
         o = o.replace(
